import QtQuick 2.0
import QtQuick.LocalStorage 2.0 as Sql

Rectangle {
    width: 360
    height: 360

    ListView {
        id: list
        width: parent.width
        height: 240

        model: ListModel{}
        delegate: Component {
            Text {
                width: ListView.view.width
                height: 25

                text: title
            }
        }
    }


    Rectangle {
        color: mouseArea.pressed ? "blue" : "red"
        anchors.bottom: parent.bottom
        width: parent.width
        height: 140

        Text {
            anchors.fill: parent
            text: "Fetch data"
        }

        MouseArea {
            id: mouseArea
            anchors.fill: parent
            onClicked: {
                var msg = { 'model' : list.model }
                worker.sendMessage(msg)
            }
        }
    }

    WorkerScript {
        id: worker
        source: "fetchdata.js"
    }

    function openDatabase() {
        return Sql.LocalStorage.openDatabaseSync("Database", "1.0", "MyDatabase", 500)
    }

    function initializeDatabase() {
        var db = openDatabase();
        db.transaction(
            function(tx) {
                tx.executeSql("CREATE TABLE IF NOT EXISTS mytable(title, id INTEGER PRIMARY KEY AUTOINCREMENT)");
            }
        );
    }

    function deleteAll() {
        var db = openDatabase();
        db.transaction(
            function(tx) {
                tx.executeSql('DELETE FROM mytable');
                        });
    }

    function addItem(title) {
        var db = openDatabase();
        db.transaction(
            function(tx) {
                tx.executeSql('INSERT INTO mytable(title) VALUES (?)', [title]);
                        });
    }

    Component.onCompleted: {
        initializeDatabase()
        deleteAll()
        for (var i=0; i < 10; i++) {
            addItem("item " + i)
        }
    }
}
